"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.executeSonarAnalysis = executeSonarAnalysis;
var _child_process = require("child_process");
var _sonarReportSummary = require("./sonarReportSummary");
var _logger = require("../../utils/logger");
var _getSonarProperties = require("./getSonarProperties");
// Js script to start sonar Server

/**
 *  cli cmd :
 *  npx ZDTestingFramework lint -- --executeFrom=ci --diffPath="" --repo="deskClientApp" --branch="" --username=""
 */

function executeSonarAnalysis(cliParams) {
  _logger.Logger.createLogFile();
  var cliObjects = cliParams;
  var command = (0, _getSonarProperties.getSonarProperties)(cliObjects);
  var child_process = (0, _child_process.spawn)("java", command);
  _logger.Logger.start('Sending report to sonarQube ...');
  child_process.stdout.on("data", function (data) {
    _logger.Logger.emit(data);
  });
  child_process.stderr.on("data", function (errorOut) {
    // error will appear here
    // Logger.error(Logger.FAILURE_TYPE, errorOut);
  });
  child_process.on("error", function (error) {
    _logger.Logger.cliLog(_logger.Logger.SUCCESS_TYPE, 'failed to send report to sonarQube ...');
    _logger.Logger.error(_logger.Logger.FAILURE_TYPE, "Error: ".concat(error.message));
  });
  child_process.on("close", function (code) {
    _logger.Logger.stop();
    (0, _sonarReportSummary.writeSummaryOfLint)(cliParams);
    _logger.Logger.cliLog(_logger.Logger.SUCCESS_TYPE, 'SonarQube analysis completed...');
    _logger.Logger.cliLog(_logger.Logger.SUCCESS_TYPE, "Report successfully sent to the server :  Status - ".concat(code === 0 ? "Success" : "Failure"));
    _logger.Logger.cliLog(_logger.Logger.PATH_TYPE, "Report URL - ".concat((0, _sonarReportSummary.getSummaryOfLint)(cliParams).reportUrl));
  });
}